GooglePlayStoreUtil class
Constructors
- GooglePlayStoreUtil({required String serviceAccount})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
latestRelease(
{required String track}) → Future< Release> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadBuild(
{required String track, required String filePath}) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited