Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
patch(
{required String buildName, required int buildNumber, required String platform, required String buildOptions, required String flutterVersion, required bool allowAssetDiffs}) → Future< void> -
release(
{required String buildName, required int buildNumber, required String platform, required String buildOptions, required String flutterVersion}) → Future< List< String> >