AppleAppStoreUtil class

Constructors

AppleAppStoreUtil({required String issuerId, required String keyId, required String privateKey, required String appId})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureSigning({required String gitUrl, bool isAdhoc = false}) Future<void>
latestRelease() Future<Release>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadBuild({required String filePath, required String keyId, required String issuerId, required String privateKey}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited